import * as React from "react";
import { createNavigatorFactory, StackRouter, usePreventRemoveContext, } from "@react-navigation/native";
import { SafeAreaProviderCompat, } from '@react-navigation/elements';
import { StyleSheet } from 'react-native';
import { Screen, ScreenStack } from 'react-native-screens';
import useCustomNavigationBuilder from "./useCustomNavigationBuilder";
function NativeStackNavigator({ id, initialRouteName, children, screenListeners, screenOptions, ...rest }) {
    const { state, descriptors, navigation, NavigationContent } = useCustomNavigationBuilder(StackRouter, {
        id,
        initialRouteName,
        children,
        screenListeners,
        screenOptions,
    });
    return (<NavigationContent>
      <CustomNativeStackView {...rest} state={state} navigation={navigation} descriptors={descriptors}/>
    </NavigationContent>);
}
export const createCustomNavigator = createNavigatorFactory(NativeStackNavigator);
const SceneView = ({ descriptor, onWillDisappear, onAppear, onDisappear, onDismissed, onHeaderBackButtonClicked, onNativeDismissCancelled, }) => {
    const { route, render } = descriptor;
    const { preventedRoutes } = usePreventRemoveContext();
    const isRemovePrevented = preventedRoutes[route.key]?.preventRemove;
    return (<Screen key={route.key} enabled style={StyleSheet.absoluteFill} gestureEnabled={true} onWillDisappear={onWillDisappear} onAppear={onAppear} onDisappear={onDisappear} onDismissed={onDismissed} isNativeStack nativeBackButtonDismissalEnabled={false} // on Android
     onHeaderBackButtonClicked={onHeaderBackButtonClicked} 
    // @ts-ignore props not exported from rn-screens
    preventNativeDismiss={isRemovePrevented} // on iOS
     onNativeDismissCancelled={onNativeDismissCancelled}>
      {render()}
    </Screen>);
};
function NativeStackViewInner({ state, navigation, descriptors }) {
    return (<ScreenStack style={styles.container}>
      {state.routes.map((route, index) => {
            const descriptor = descriptors[route.key];
            const isFocused = state.index === index;
            const previousKey = state.routes[index - 1]?.key;
            const nextKey = state.routes[index + 1]?.key;
            const previousDescriptor = previousKey
                ? descriptors[previousKey]
                : undefined;
            const nextDescriptor = nextKey ? descriptors[nextKey] : undefined;
            return (<SceneView key={route.key} index={index} focused={isFocused} descriptor={descriptor} previousDescriptor={previousDescriptor} nextDescriptor={nextDescriptor}/>);
        })}
    </ScreenStack>);
}
export default function FlowStackView(props) {
    return (<SafeAreaProviderCompat>
      <NativeStackViewInner {...props}/>
    </SafeAreaProviderCompat>);
}
const styles = StyleSheet.create({
    container: {
        flex: 1,
    },
    scene: {
        flex: 1,
        flexDirection: 'column-reverse',
    },
    absolute: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
    },
    translucent: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        zIndex: 1,
        elevation: 1,
    },
    background: {
        overflow: 'hidden',
    },
});
