import * as React from "react";
import { SafeAreaProviderCompat } from "@react-navigation/elements";
import { StyleSheet } from "react-native";
import { Screen, ScreenStack, ScreenStackHeaderConfig, } from "react-native-screens";
import useCustomNavigationBuilder from "./useCustomNavigationBuilder";
import StackRouter from "./StackRouter";
function NativeStackNavigator({ id, initialRouteName, children, screenListeners, screenOptions, ...rest }) {
    const { state, descriptors, NavigationContent } = useCustomNavigationBuilder(StackRouter, {
        id,
        initialRouteName,
        children,
        screenListeners,
        screenOptions,
    });
    return (<NavigationContent>
      <CustomNativeStackView {...rest} state={state} descriptors={descriptors}/>
    </NavigationContent>);
}
export const createCustomNavigator = () => ({
    Navigator: NativeStackNavigator,
    Screen: () => null,
});
const SceneView = ({ descriptor }) => {
    const { route, render } = descriptor;
    return (<Screen key={route.key} enabled style={StyleSheet.absoluteFill} gestureEnabled={true} isNativeStack nativeBackButtonDismissalEnabled={false} // on Android
    >
      {/** header doesn't work: can't go back and forth */}
      <ScreenStackHeaderConfig title={"toto"} translucent={false}>
      </ScreenStackHeaderConfig>
      {render()}
    </Screen>);
};
function NativeStackViewInner({ state, descriptors, }) {
    return (<ScreenStack style={{
            flex: 1,
        }}>
      {state.routes.map((route) => {
            const descriptor = descriptors[route.key];
            return <SceneView key={route.key} descriptor={descriptor}/>;
        })}
    </ScreenStack>);
}
export default function CustomNativeStackView(props) {
    return (<SafeAreaProviderCompat>
      <NativeStackViewInner {...props}/>
    </SafeAreaProviderCompat>);
}
