import React from "react";
import { NavigationBuilderContext } from "./NavigationBuilderContext";
export function useCustomOnAction({ router, getState, setState, key, routerConfigOptions, }) {
    const { onAction: onActionParent, onRouteFocus: onRouteFocusParent, } = React.useContext(NavigationBuilderContext);
    const onAction = React.useCallback((action) => {
        const state = getState();
        if (typeof action.target !== "string" || action.target === state.key) {
            let result = router.getStateForAction(state, action, routerConfigOptions);
            // BONUS: target
            // If a target is specified and set to current navigator, the action shouldn't bubble
            // So instead of `null`, we use the state object for such cases to signal that action was handled
            result =
                result === null && action.target === state.key ? state : result;
            if (result !== null) {
                if (state !== result) {
                    setState(result);
                }
                if (onRouteFocusParent !== undefined) {
                    // Some actions such as `NAVIGATE` also want to bring the navigated route to focus in the whole tree
                    // This means we need to focus all of the parent navigators of this navigator as well
                    const shouldFocus = router.shouldActionChangeFocus(action);
                    if (shouldFocus && key !== undefined) {
                        onRouteFocusParent(key);
                    }
                }
                return true;
            }
        }
        if (onActionParent !== undefined) {
            // Bubble action to the parent if the current navigator didn't handle it
            if (onActionParent(action)) {
                return true;
            }
        }
        return false;
    }, [
        getState,
        key,
        onActionParent,
        onRouteFocusParent,
        router,
        setState,
    ]);
    return onAction;
}
