import { CommonActions, } from "@react-navigation/routers";
import * as React from "react";
/**
 * Hook to cache navigation objects for each screen in the navigator.
 * It's important to cache them to make sure navigation objects don't change between renders.
 * This lets us apply optimizations like `React.memo` to minimize re-rendering screens.
 */
export function useNavigationCache({ state, getState, navigation, router, }) {
    const base = React.useMemo(() => {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const { emit, ...rest } = navigation;
        const actions = {
            ...router.actionCreators,
            ...CommonActions,
        };
        const dispatch = () => {
            throw new Error("Actions cannot be dispatched from a placeholder screen.");
        };
        const helpers = Object.keys(actions).reduce((acc, name) => {
            acc[name] = dispatch;
            return acc;
        }, {});
        return {
            ...rest,
            ...helpers,
            dispatch,
        };
    }, [navigation, router.actionCreators]);
    const navigations = state.routes.reduce((acc, route) => {
        const dispatch = (thunk) => {
            const action = typeof thunk === "function" ? thunk(getState()) : thunk;
            if (action != null) {
                navigation.dispatch({ source: route.key, ...action });
            }
        };
        const actions = {
            ...router.actionCreators,
            ...CommonActions,
        };
        const helpers = Object.keys(actions).reduce((acc, name) => {
            acc[name] = (...args) => dispatch(actions[name](...args));
            return acc;
        }, {});
        acc[route.key] = {
            ...base,
            ...helpers,
            dispatch,
            // isFocused, ...
        };
        return acc;
    }, {});
    return {
        navigations,
    };
}
